/*  Copyright (C) 2020 Andrea G. Monaco
 *
 *  This file is part of libre-sapienza.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */


#include "config.h"


#define BUFFER_LENGTH   1024
#define TOKEN_LENGTH    512


#include <stdio.h>
#include <unistd.h>
#include <stdlib.h>
#include <string.h>
#include <locale.h>

#include <curl/curl.h>
#include <jansson.h>

#include <libintl.h>
#define _(String) gettext (String)
  
#include "exam.h"
#include "input.h"
#include "main.h"
#include "network.h"
#include "tax.h"
#include "student.h"


int studentid; /* student id of the current login */


int
main (int argc, char *argv[])
{
  const char *pass = NULL;
  
  //json_t *av_exams;
  //struct exam_l *av_exams_list = NULL;

  int choice;
  
  setlocale (LC_ALL, "");
  bindtextdomain ("libre-sapienza", "locale");
  textdomain ("locale");
  
  if (curl_global_init (CURL_GLOBAL_ALL))
    {
      fprintf (stderr, _("could not initialize libcurl\n"));
      exit (1);
    }

  curl_handle = curl_easy_init ();
  if (!curl_handle)
    {
      fprintf (stderr, _("could not create libcurl handle\n"));
      exit (1);
    }

  print_startup_message ();
  
  printf (_("student id: "));
  studentid = read_int (16);
  
  pass = read_password ();
  
  attempt_login (pass);

  if (!token)
    {
      fprintf (stderr, _("exiting...\n"));
      exit (1);
    }

  choice = prompt_and_read_user_action ();
  while (choice != 7)
    {
      switch (choice)
	{
	case 1:
	  /* try to load and print available exams */
	  request_available_exams ();
	  print_available_exams ();
	  break;
	case 2:
	  request_completed_exams ();
	  print_completed_exams ();
	  break;
	case 3:
	  request_active_reservations ();
	  print_active_reservations ();
	  break;
	case 4:
	  request_student_info ();
	  print_student_info ();
	  break;
	case 5:
	  request_paid_taxes ();
	  print_taxes_json (1);
	  break;
	case 6:
	  request_unpaid_taxes ();
	  print_taxes_json (0);
	  break;
	default:
	  fprintf (stderr, _("not an option!\n\n"));
	  break;
	}
      choice = prompt_and_read_user_action ();
    }

  printf (_("exiting...\n"));
  curl_easy_cleanup (curl_handle);
  
  return 0;
}


void
print_version_and_exit (void)
{
  printf (_("libre-sapienza 0.1\n"
	    "Copyright (C) 2020 Andrea G. Monaco.\n"
	    "License GPLv3+: GNU GPL version 3 or later <https://gnu.org/licenses/gpl.html>\n"
	    "This is free software: you are free to change and redistribute it.\n"
	    "There is NO WARRANTY, to the extent permitted by law.\n"));

  exit (0);
}


void
print_help_and_exit (void)
{
  printf (_("Report bugs to: monacoandrea94@gmail.com\n"
	    "libre-sapienza home page: none!\n"));
  exit (0);
}


void
print_startup_message (void)
{
  printf (_("libre-sapienza  Copyright (C) 2020  Andrea G. Monaco\n"
	    "This program comes with ABSOLUTELY NO WARRANTY; for details type `show w'.\n"
	    "This is free software, and you are welcome to redistribute it\n"
	    "under certain conditions; type `show c' for details.\n\n"));
}
